@@ -3,6 +3,7 @@ import os
 import json
 import random
 import time
+# import sys
 from time import sleep
 from urllib.parse import quote_plus
 from collections import defaultdict
@@ -16,10 +17,12 @@ from lxml import etree
 from fake_user_agent import settings
 from fake_user_agent.log import logger
 from fake_user_agent.errors import FakeUserAgentError
+from fake_user_agent.parse import get_browser_input
 
 
 all_versions = defaultdict(list)
 
+TEMP_FILE = settings.TEMP_FILE # TMEP_FILE is a list
 
 async def fetch(url, session):
     attempt = 0
@@ -40,9 +43,6 @@ async def fetch(url, session):
         except asyncio.TimeoutError:
             logger.error("Timed out during fetching %s. Retrying...", url)
             sleep(settings.HTTP_DELAY)
-        except aiohttp.client_exceptions.ClientOSError:
-            logger.error("%s terminated connection. Retrying...", url)
-            sleep(settings.HTTP_DELAY)
         except Exception:
             logger.exception("Error occurred during fetching %s.", url)
         else:
@@ -61,12 +61,13 @@ async def parse(browser, session):
         ]
         all_versions[browser].extend(versions)
 
-
 def write(path, data):
     rm_tempfile()
+    global TEMP_FILE
     with open(path, encoding="utf-8", mode="wt") as f:
         dumped = json.dumps(data)
         f.write(dumped)
+    TEMP_FILE = settings.TEMP_FILE
 
 
 def read(path):
@@ -76,10 +77,11 @@ def read(path):
 
 
 def rm_tempfile():
-    tempfile_list = settings.TEMP_FILE
-    if tempfile_list:
-        for i in tempfile_list:
+    global TEMP_FILE
+    if TEMP_FILE:
+        for i in TEMP_FILE:
             os.remove(i)
+            TEMP_FILE = []
     else:
         return
 
@@ -106,8 +108,8 @@ async def main(browser=None, use_tempfile=True):
         if browser not in list(settings.BROWSERS.keys()):
             raise FakeUserAgentError("This browser is not supported.")
 
-    if settings.TEMP_FILE:
-        data = read(settings.TEMP_FILE[-1])
+    if TEMP_FILE:
+        data = read(TEMP_FILE[-1])
         return random_choose(browser, data)
 
     else:
@@ -123,7 +125,8 @@ async def main(browser=None, use_tempfile=True):
 
 # Get user agent from terminal
 def get_input():
-    browser = input("Input a browser name or hit <enter> not to specify browser: ")
+    browser = get_browser_input()
+    # browser = input("Input a browser name or hit <enter> not to specify browser: ")
     print(asyncio.run(main(browser=browser, use_tempfile=True)))
 
 
