@@ -1,5 +1,6 @@
 """Generate fake useragent using threading. This is only for offering another solution. Not actually called in the published pkg"""
 import os
+# import sys
 import json
 import random
 from time import sleep
@@ -12,6 +13,7 @@ from collections import defaultdict
 
 from lxml import etree
 
+# sys.path.append(os.path.dirname(os.path.dirname(os.path.abspath(__file__))))
 
 all_versions = defaultdict(list)
 
@@ -83,9 +85,11 @@ def load_by_threadpool(use_cache_server=True):
 
 def write(path, data):
     rm_tempfile()
+    global TEMP_FILE
     with open(path, encoding="utf-8", mode="wt") as f:
         dumped = json.dumps(data)
         f.write(dumped)
+    TEMP_FILE = settings.TEMP_FILE
 
 
 def read(path):
@@ -95,10 +99,11 @@ def read(path):
 
 
 def rm_tempfile():
-    tempfile_list = settings.TEMP_FILE
-    if tempfile_list:
-        for i in tempfile_list:
+    global TEMP_FILE
+    if TEMP_FILE:
+        for i in TEMP_FILE:
             os.remove(i)
+            TEMP_FILE = []
     else:
         return
 
@@ -125,8 +130,8 @@ def user_agent(browser=None, use_tempfile=True):
         if browser not in list(settings.BROWSERS.keys()):
             raise FakeUserAgentError("This browser is not supported.")
 
-    if settings.TEMP_FILE:
-        data = read(settings.TEMP_FILE[-1])
+    if TEMP_FILE:
+        data = read(TEMP_FILE[-1])
         return random_choose(browser, data)
 
     else:
@@ -140,8 +145,11 @@ if __name__ == "__main__":
     import settings
     from log import logger
     from errors import FakeUserAgentError
+    from parse import get_browser_input
 
-    browser = input("Input a browser name or hit <enter> not to specify browser: ")
+    TEMP_FILE = settings.TEMP_FILE # TMEP_FILE is a list
+
+    browser = get_browser_input()
     print(user_agent(browser=browser, use_tempfile=True))
 
 
@@ -149,3 +157,5 @@ else:
     from fake_user_agent import settings
     from fake_user_agent.log import logger
     from fake_user_agent.errors import FakeUserAgentError
+
+    TEMP_FILE = settings.TEMP_FILE # TMEP_FILE is a list
